==> keycloak-parent-24.0.2-source-release.zip: keycloak-parent-24.0.2/js/apps/account-ui/src/index.ts <==
export { PersonalInfo } from "./personal-info/PersonalInfo";
export { ErrorPage } from "./root/ErrorPage";
export { Header } from "./root/Header";
export { KeycloakProvider, useEnvironment } from "./root/KeycloakContext";
export { PageNav } from "./root/PageNav";
export { DeviceActivity } from "./account-security/DeviceActivity";
export { LinkedAccounts } from "./account-security/LinkedAccounts";
export { SigningIn } from "./account-security/SigningIn";
export type {
  AccountLinkUriRepresentation,
  Client,
  ClientRepresentation,
  ConsentRepresentation,
  ConsentScopeRepresentation,
  CredentialContainer,
  CredentialMetadataRepresentation,
  CredentialRepresentation,
  CredentialTypeMetadata,
  DeviceRepresentation,
  Group,
  LinkedAccountRepresentation,
  Permission,
  Permissions,
  Resource,
  Scope,
  SessionRepresentation,
  UserProfileAttributeMetadata,
  UserProfileMetadata,
  UserRepresentation,
} from "./api/representations";
export { Applications } from "./applications/Applications";
export { EmptyRow } from "./components/datalist/EmptyRow";
export { Page } from "./components/page/Page";
export { ContentComponent } from "./content/ContentComponent";
export { Groups } from "./groups/Groups";
export { EditTheResource } from "./resources/EditTheResource";
export { PermissionRequest } from "./resources/PermissionRequest";
export { Resources } from "./resources/Resources";
export { ResourcesTab } from "./resources/ResourcesTab";
export { ResourceToolbar } from "./resources/ResourceToolbar";
export { SharedWith } from "./resources/SharedWith";
export { ShareTheResource } from "./resources/ShareTheResource";
export {
  deleteConsent,
  deleteCredentials,
  deleteSession,
  getApplications,
  getCredentials,
  getDevices,
  getGroups,
  getLinkedAccounts,
  getPermissionRequests,
  getPersonalInfo,
  getSupportedLocales,
  linkAccount,
  savePersonalInfo,
  unLinkAccount,
} from "./api/methods";

==> keycloak-parent-25.0.0-source-release.zip: keycloak-parent-25.0.0/js/apps/account-ui/src/index.ts <==
export { PersonalInfo } from "./personal-info/PersonalInfo";
export { ErrorPage } from "./root/ErrorPage";
export { Header } from "./root/Header";
export { PageNav } from "./root/PageNav";
export { DeviceActivity } from "./account-security/DeviceActivity";
export { LinkedAccounts } from "./account-security/LinkedAccounts";
export { SigningIn } from "./account-security/SigningIn";
export type {
  AccountLinkUriRepresentation,
  Client,
  ClientRepresentation,
  ConsentRepresentation,
  ConsentScopeRepresentation,
  CredentialContainer,
  CredentialMetadataRepresentation,
  CredentialRepresentation,
  CredentialTypeMetadata,
  DeviceRepresentation,
  Group,
  LinkedAccountRepresentation,
  Permission,
  Permissions,
  Resource,
  Scope,
  SessionRepresentation,
  UserProfileAttributeMetadata,
  UserProfileMetadata,
  UserRepresentation,
} from "./api/representations";
export { Applications } from "./applications/Applications";
export { EmptyRow } from "./components/datalist/EmptyRow";
export { Page } from "./components/page/Page";
export { ContentComponent } from "./content/ContentComponent";
export { Groups } from "./groups/Groups";
export { EditTheResource } from "./resources/EditTheResource";
export { PermissionRequest } from "./resources/PermissionRequest";
export { Resources } from "./resources/Resources";
export { ResourcesTab } from "./resources/ResourcesTab";
export { ResourceToolbar } from "./resources/ResourceToolbar";
export { SharedWith } from "./resources/SharedWith";
export { Oid4Vci } from "./oid4vci/Oid4Vci";
export { ShareTheResource } from "./resources/ShareTheResource";
export {
  deleteConsent,
  deleteSession,
  getApplications,
  getCredentials,
  getDevices,
  getGroups,
  getLinkedAccounts,
  getPermissionRequests,
  getPersonalInfo,
  getSupportedLocales,
  linkAccount,
  savePersonalInfo,
  unLinkAccount,
} from "./api/methods";
